      subroutine mie_melt(freq, temp, iwc, lwc, f_snow,
     &                    ksca, asca, gsca, pbck)
      

c     Compute the extinction, absorption, asymmetry parameter and
c     backscatter for a given water content of melting particles, 
c     which are assumed to be a snow and rain mixture with the
c     snow fraction specified by "f_snow". Snow and rain water
c     content in [g/m^3] are given by "iwc" and "lwc", respectively.
c     The dielectric constant of melting particles is approximated
c     by the 50-50 mixture of ice and water.

c     Input:
c     freq		frequency of radiation [GHz]
c     temp		temperature of particles [K]
c     iwc		water content of snow distribution [g/m**3]
c     lwc		water content of rain distribution [g/m**3]
c     f_snow            number fraction of snow to the rain/snow mixture

c     Output:
c     ksca		extinction coefficient [1/km]
c     asca		single-scatter albedo []
c     gsca		asymmetry factor []
c     pbck		backscatter phase function/(4*pi) []
c

      implicit none

      integer *4 i
      
      real *4 freq
      real *4 temp 
      real *4 lwc,iwc
      real *4 ksca 
      real *4 asca 
      real *4 gsca
      real *4 pbck
      real *4 f_snow

      real *4 wave
      real *4 pi
      real *4 rad
      real *4 densice
      real *4 densliq
      real *4 density
      real *4 lam
      real *4 n0s,n0r
      real *4 denss,densr
      real *4 num,num_s,num_r
      real *4 faa
      real *4 eicere
      real *4 eiceim 
      real *4 qext
      real *4 qsca
      real *4 asym
      real *4 qbsca
      real *4 bext
      real *4 bsca
      real *4 bsym
      real *4 bq11
      
      real *8 xd 
      real *8 freqhzd
      real *8 freqd
      real *8 tempd
      real *8 sald
      real *8 ewatred
      real *8 ewatimd
      real *8 eicered
      real *8 eiceimd
      real *8 qscad
      real *8 qextd
      real *8 asymd
      real *8 qbscad

      complex *8 eice
      complex *8 eair
      complex *8 ei

      complex *16 ewatd
      complex *16 eid
      complex *16 crefd,crefd_s,crefd_r

      data pi/3.14159265/
      data densliq/1.0e+3/
      data densice/0.917e+3/

c      
c     Assign some useful constants
      wave=300./freq
      
c
c     Begin by checking if hydrometeors of this species are present.
c     If not, set scattering parameters to zero and return.
c
      if(lwc .lt. 0.001 .and. iwc .lt. 0.001) then
        ksca=0.
        asca=0.
        gsca=0.
        pbck=0.
        return
      endif

c
c     If hydrometeors are present, initialize the scattering parameters
c
      bext=0.
      bsca=0.
      bsym=0.
      bq11=0.

c
c     Loop over particle sizes:

c     increments of particle radius are 0.05 mm; the particle
c     size distribution is expressed as a particle number density,
c     num, per radius increment; the original psd is
c     n(D) = n0s * exp(-lam * D) where n is the number density
c     per diameter increment, n0s is the distribution intercept,
c     lam is the slope of the distribution of ln(n(D)), and D is
c     the particle diameter. It is assumed here that n0s is
c     and lwc are prescribed, and lam is therefore constrained 
c     to yield the prescribed water content:
c     lwc = integral {n(D) * pi * (D**3) * density(D) * dD/6}
c     therefore:
c     lam=(n0s*pi*density/lwc)**(0.25)

c
c     prescribe n0s [1/m**4]
      n0s=1.0e+8
      n0r=2.2e+7
c     prescribe particle density
c     denss [kg/m**3]
      denss=0.1e+3 
      densr=1.e+3

      do i=0,200
c
c Snow DSD
c 
        rad=0.025+0.05*float(i)
        xd=dble(2.*pi*rad/wave)
        density=denss
        lam=(n0s*pi*density/((iwc+lwc)*(1.e-3)))**(0.25)
        ! num is in terms of radius - factors of 2 account for conversion
        num_s=2.*n0s*exp(-lam*2.*rad*(1.e-3))
c
c Rain DSD
c
        density=densr
        lam=(n0r*pi*density/((iwc+lwc)*(1.e-3)))**(0.25)
        ! num is in terms of radius - factors of 2 account for conversion
        num_r=2.*n0r*exp(-lam*2.*rad*(1.e-3))
c
c       complex refractive index of snow
c
        freqd=dble(freq)
        tempd=dble(temp)
        call iceoptic(freqd,tempd,eicered,eiceimd)
        eicere=real(eicered)
        eiceim=real(eiceimd)
        eice=cmplx(eicere,eiceim)
        eair=cmplx(1.0006,0.0)

c       calculate dielectric constant of snow as
c       ice matrix with air inclusions, using
c       Maxwell-Garnett mixing
        faa=1.-(denss/densice)
        call mg_ellips(faa,eice,eair,ei)
        eid=dcmplx(ei)
        crefd_s=cdsqrt(eid)
c
c       complex refractive index of liquid water
c
        freqhzd=dble(freq*1.e+9)
        sald=0.d0
        call watoptic(freqhzd,tempd,sald,
     +   ewatred,ewatimd)
        ewatd=dcmplx(ewatred,ewatimd)
        crefd_r=cdsqrt(ewatd)
c
c       define melting particle properties
c
        num   = f_snow  * num_s   + (1.  -     f_snow)  * num_r
        crefd = .5d0 * crefd_s + .5d0 * crefd_r
c
c       call Mie program
c 
        call mie_sphere(xd,crefd,qscad,qextd,asymd,qbscad)

        qext=real(qextd)
        qsca=real(qscad)
        asym=real(asymd)
        qbsca=real(qbscad)
        
c
c       integrate over particle size distribution;

        bext=bext+num*qext*pi*rad*rad*(0.05)*1.e-6
        bsca=bsca+num*qsca*pi*rad*rad*(0.05)*1.e-6
        bsym=bsym+num*qsca*asym*pi*rad*rad*(0.05)*1.e-6
        bq11=bq11+num*qbsca*pi*rad*rad*(0.05)*1.e-6

      end do

c
c     check for distribution with very small extinction;
c     set parameters to zero to avoid numerical problems
      if( bext .gt. 1.e-6) then

        ksca=bext
        asca=bsca/bext
        gsca=bsym/bsca
        pbck=bq11/bsca

      else

        ksca=0.
        asca=0.
        gsca=0.
        pbck=0.

      end if

      return
      end
