      subroutine mie_clw_bs(freq, temp, lwc, ksca, asca, gsca, pbck)
      

c     Compute the extinction, absorption, asymmetry parameter and
c     backscatter for a given water content of cloud water in [g/m^3], 
c     using the Liou (1992) particle size distribution.

c     Input:
c     freq		frequency of radiation [GHz]
c     temp		temperature of particles [K]
c     lwc		water content of cloud water distribution [g/m**3]

c     Output:
c     ksca		extinction coefficient [1/km]
c     asca		single-scatter albedo []
c     gsca		asymmetry factor []
c     pbck		backscatter phase function/(4*pi) []
c

      implicit none

      integer *4 i
      
      real *4 freq
      real *4 temp 
      real *4 lwc
      real *4 ksca 
      real *4 asca 
      real *4 gsca
      real *4 pbck

      real *4 refmed
      real *4 wave
      real *4 pi
      real *4 densice
      real *4 densliq
      real *4 rad
      real *4 density
      real *4 lam
      real *4 densr
      real *4 rmode
      real *4 num
      real *4 qext
      real *4 qsca
      real *4 asym
      real *4 qbsca
      real *4 bext
      real *4 bsca
      real *4 bsym
      real *4 bq11
      
      real *8 xd 
      real *8 freqhzd
      real *8 freqd
      real *8 tempd
      real *8 sald
      real *8 ewatred
      real *8 ewatimd
      real *8 qscad
      real *8 qextd
      real *8 asymd
      real *8 qbscad

      complex *16 ewatd
      complex *16 crefd

      data pi/3.14159265/
      data densliq/1.0e+3/
      data densice/0.917e+3/
c      
c     Assign some useful constants
      refmed=1.0
      wave=300./freq
      
c
c     Begin by checking if hydrometeors of this species are present.
c     If not, set scattering parameters to zero and return.
c
      if(lwc .lt. 0.001) then
        ksca=0.
        asca=0.
        gsca=0.
        pbck=0.
        return
      endif

c
c     If hydrometeors are present, initialize the scattering parameters
c
      bext=0.
      bsca=0.
      bsym=0.
      bq11=0.

c
c     Loop over particle sizes:

c     increments of particle radius are 0.0005 mm; the particle
c     size distribution is expressed as a particle number density,
c     num, per radius increment.  The particle size distribution
c     is a gamma function from Liou (1992).  The distribution is
c     controlled by the mode radius, rmode [microns]

      rmode=6.
c
      do i=0,200
        rad=0.00025+0.0005*float(i)
        xd=dble(2.*pi*rad/wave)
        density=densliq

        num=3.*lwc*166.629*(1.e+21)*
     +   ((rad*1.e+3)**6.)*exp(-6.*rad*(1.e+3)/rmode)/
     +   (4.*pi*density*(rmode**10.))

c
c       complex refractive index of liquid water
c
        freqhzd=dble(freq*1.e+9)
        freqd=dble(freq)
        tempd=dble(temp)
        sald=0.d0
        call watoptic(freqhzd,tempd,sald,
     +   ewatred,ewatimd)
        ewatd=dcmplx(ewatred,ewatimd)
        crefd=cdsqrt(ewatd)

c
c       call Mie program
c 
        call mie_sphere(xd,crefd,qscad,qextd,asymd,qbscad)

        qext=real(qextd)
        qsca=real(qscad)
        asym=real(asymd)
        qbsca=real(qbscad)
        
c
c       integrate over particle size distribution;

        bext=bext+num*qext*pi*rad*rad*(0.0005)*1.e-6
        bsca=bsca+num*qsca*pi*rad*rad*(0.0005)*1.e-6
        bsym=bsym+num*qsca*asym*pi*rad*rad*(0.0005)*1.e-6
        bq11=bq11+num*qbsca*pi*rad*rad*(0.0005)*1.e-6

      end do

c
c     check for distribution with very small extinction;
c     set parameters to zero to avoid numerical problems
      if( bext .gt. 1.e-6) then

        ksca=bext
        asca=bsca/bext
        gsca=bsym/bsca
        pbck=bq11/bsca

      else

        ksca=0.
        asca=0.
        gsca=0.
        pbck=0.

      end if

      return
      end
