      subroutine mie_rain_bs(freq, temp, lwc, 
     &                       ksca, asca, gsca, pbck, bscaR)
      

c     Compute the extinction, absorption, asymmetry parameter and
c     backscatter for a given water content of rain in [g/m^3], and
c     a particle size distribution n(D) with intercept n0r (n0 rain).

c     Input:
c     freq		frequency of radiation [GHz]
c     temp		temperature of particles [K]
c     lwc		water content of rain distribution [g/m**3]

c     Output:
c     ksca		extinction coefficient [1/km]
c     asca		single-scatter albedo []
c     gsca		asymmetry factor []
c     pbck		backscatter phase function/(4*pi) []
c

      implicit none

      integer *4 i
      
      real *4 freq
      real *4 temp 
      real *4 lwc
      real *4 ksca 
      real *4 asca 
      real *4 gsca
      real *4 pbck

      real *4 wave
      real *4 pi
      real *4 densice
      real *4 densliq
      real *4 rad, dr, dD
      real *4 density
      real *4 lam
      real *4 n0r
      real *4 densr
      real *4 num
      real *4 qext
      real *4 qsca
      real *4 asym
      real *4 qbsca
      real *4 bext
      real *4 bsca
      real *4 bsym
      real *4 bq11
      
      real *4 D, mu
      integer imax

      real *8 xd 
      real *8 freqhzd
      real *8 freqd
      real *8 tempd
      real *8 sald
      real *8 ewatred
      real *8 ewatimd
      real *8 qscad
      real *8 qextd
      real *8 asymd
      real *8 qbscad

      real bscaR,mom6

      complex *16 ewatd
      complex *16 crefd

      data pi/3.14159265/
      data densliq/1.0/ !! in g/cm3

      Parameter ( mu = 3. )
c      
c     Assign some useful constants
      wave=300./freq
c
c     Begin by checking if hydrometeors of this species are present.
c     If not, set scattering parameters to zero and return.
c
      if(lwc .lt. 0.001) then
        ksca=0.
        asca=0.
        gsca=0.
        pbck=0.
        return
      endif

c
c     If hydrometeors are present, initialize the scattering parameters
c
      bext=0.
      bsca=0.
      bsym=0.
      bq11=0.
      mom6=0.
c
c     Loop over particle sizes:

c     prescribe particle density
      densr=densliq 
      dr = 0.05
      dD = dr * 2.
      imax = nint(10./dr)
c     prescribe n0r [1/mm/m**3]
      n0r=2.2e+4
c
      do i=0,imax
        rad=dr*.5 + dr*float(i)
        xd=dble(2.*pi*rad/wave)
        density=densr
        D = 2.*rad
c     lam in [1/mm]
        lam=(n0r*pi*density*1.e-3/lwc)**(0.25)
        num=n0r*exp(-lam*D)
c
c       complex refractive index of liquid water
c
        freqhzd=dble(freq*1.e+9)
        freqd=dble(freq)
        tempd=dble(temp)
        sald=0.d0
        call watoptic(freqhzd,tempd,sald,
     +   ewatred,ewatimd)
        ewatd=dcmplx(ewatred,ewatimd)
        crefd=cdsqrt(ewatd)
c
c       call Mie program
c 
        call mie_sphere(xd,crefd,qscad,qextd,asymd,qbscad)

        qext=real(qextd)
        qsca=real(qscad)
        asym=real(asymd)
        qbsca=real(qbscad)
c       
c       integrate over particle size distribution;
c
        bext=bext+num*qext *pi*rad*rad*dD
        bsca=bsca+num*qsca *pi*rad*rad*dD
        bsym=bsym+num*qsca *asym*pi*rad*rad*dD
        bq11=bq11+num*qbsca*pi*rad*rad*dD
        mom6=mom6+num*      D**6      *dD
      end do

c
c     check for distribution with very small extinction;
c     set parameters to zero to avoid numerical problems
      if( bext .gt. 1.e-6) then

        ksca=bext
        asca=bsca/bext
        gsca=bsym/bsca
        pbck=bq11/bsca

      else

        ksca=0.
        asca=0.
        gsca=0.
        pbck=0.

      end if
      bscaR = pi**5/wave**4*mom6 *
     &        (cdabs((ewatd-1.)/(ewatd+2.)))**2
c
c Unit conversion [mm2/m-3] -> [km-1]
c 
      ksca = ksca  * 1.e-3
      bscaR= bscaR * 1.e-3
C 
      return
      end
